comprel: Compare split-half reliabilities

View source: R/cormean.R

comprelR Documentation

Compare split-half reliabilities

Description

Compare split-half reliabilities

Usage

comprel(x, y, alternative = c("two.sided", "less", "greater"))

Arguments

x, y

Either rapidsplit objects outputted by rapidsplithalf(), or raw vectors or permutation-based split-half reliabilities.

alternative

The type of test to perform: "two.sided", "less" (x < y), or "greater" (x > y).

Details

For each split-half correlation in x, this computes the percentage of individual split-half correlations in y that are smaller; these percentages are then averaged and modified in accordance with the test requested in alternative to give the p-value.

Value

The p-value for the difference.

Note

A large number of splits (>10,000) is recommended to get an accurate p-value.

Author(s)

Sercan Kahveci

Examples


# Here we will demonstrate that the reliability of the practice trials in the IAT
# is higher than the reliability of the non-practice trials.
data(raceIAT)
rel1 <- rapidsplit(data=raceIAT[raceIAT$blocktype=="practice",],
                   subjvar="session_id",diffvars="congruent",
                   subscorevar="blocktype",aggvar="latency",splits=1000,standardize=TRUE)
                   
rel2 <- rapidsplit(data=raceIAT[raceIAT$blocktype=="full",],
                   subjvar="session_id",diffvars="congruent",
                   subscorevar="blocktype",aggvar="latency",splits=1000,standardize=TRUE)
comprel(rel1,rel2,alternative="greater")


rapidsplithalf documentation built on April 15, 2026, 5:06 p.m.