| correlation-tools | R Documentation |
Helper functions to compute important statistics from correlation coefficients.
r2z(r)
z2r(z)
r2t(r, n)
t2r(t, n)
r2p(r, n)
rconfint(r, n, alpha = 0.05)
compcorr(r1, r2, n1, n2)
## S3 method for class 'compcorr'
print(x, ...)
r, r1, r2 |
Correlation values. |
z |
Z-scores. |
n, n1, n2 |
Sample sizes. |
t |
t-scores. |
alpha |
The significance level to use. |
x |
A |
... |
Ignored. |
For r2z(), z2r, r2t, t2r, and r2p,
a numeric vector with the requested transformation applied.
For rconfint(), a numeric vector with two values representing
the lower and upper confidence intervals of the correlation coefficient.
For compcorr(), a compcorr object containing
a z and p value for the requested comparison,
which can be printed with print.compcorr().
r2z(): Converts correlation coefficients to z-scores.
z2r(): Converts z-scores to correlation coefficients.
r2t(): Converts correlation coefficients to t-scores.
t2r(): Converts t-scores to correlation coefficients.
r2p(): Computes the two-sided p-value for a given correlation.
rconfint(): Computes confidence intervals for one or multiple correlation coefficients.
compcorr(): Computes the significance of the difference between two correlation coefficients.
print(compcorr): Computes the significance of the difference between two correlation coefficients.
compcorr() should not be used to compare permutation-based reliabilities.
In that context, it has an excessive type-1 error. Use [comprel()] instead.
Sercan Kahveci
cormean
z <- r2z(.5)
r <- z2r(z)
t<-r2t(r,30)
r<-t2r(t,30)
r2p(r,30)
print(rconfint(r,30))
print(compcorr(.5,.7,20,20))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.