spearmanBrown: Spearman-Brown correction Perform a Spearman-Brown correction...

View source: R/spearmanbrown.R

spearmanBrownR Documentation

Spearman-Brown correction Perform a Spearman-Brown correction on the provided correlation score.

Description

Spearman-Brown correction Perform a Spearman-Brown correction on the provided correlation score.

Usage

spearmanBrown(r, ntests = 2, fix.negative = c("mirror", "nullify", "none"))

Arguments

r

To-be-corrected correlation coefficient.

ntests

An integer indicating how many times larger the full test is, for which the corrected correlation coefficient is being computed.

fix.negative

How will negative input values be dealt with?

  • "mirror" submits the absolute correlations to the formula and restores the original sign afterwards.

  • "nullify" sets negative correlations to zero.

  • "none" leaves them as-is (not recommended).

Details

When ntests=2, the formula will compute what the correlation coefficient would be if the test were twice as long.

Value

Spearman-Brown corrected correlation coefficients.

Author(s)

Sercan Kahveci

See Also

requiredTestSize() to compute how many items a test with a known reliability needs, to achieve a goal reliability.

Examples

spearmanBrown(.5)


rapidsplithalf documentation built on April 15, 2026, 5:06 p.m.