| comprel | R Documentation |
Compare split-half reliabilities
comprel(x, y, alternative = c("two.sided", "less", "greater"))
x, y |
Either |
alternative |
The type of test to perform: "two.sided", "less" (x < y), or "greater" (x > y). |
For each split-half correlation in x,
this computes the percentage of individual split-half correlations in y
that are smaller; these percentages are then averaged and modified in accordance
with the test requested in alternative to give the p-value.
The p-value for the difference.
A large number of splits (>10,000) is recommended to get an accurate p-value.
Sercan Kahveci
# Here we will demonstrate that the reliability of the practice trials in the IAT
# is higher than the reliability of the non-practice trials.
data(raceIAT)
rel1 <- rapidsplit(data=raceIAT[raceIAT$blocktype=="practice",],
subjvar="session_id",diffvars="congruent",
subscorevar="blocktype",aggvar="latency",splits=1000,standardize=TRUE)
rel2 <- rapidsplit(data=raceIAT[raceIAT$blocktype=="full",],
subjvar="session_id",diffvars="congruent",
subscorevar="blocktype",aggvar="latency",splits=1000,standardize=TRUE)
comprel(rel1,rel2,alternative="greater")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.