| rapidsplithalf | R Documentation |
Accurately estimates the reliability of cognitive tasks using a fast and flexible
permutation-based split-half reliability algorithm
that supports stratified splitting while maintaining equal split sizes.
See Kahveci, Bathke, and Blechert (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3758/s13423-024-02597-y")} for details.
To learn more about rapidsplithalf, view the introductory vignette:
vignette("rapidsplithalf",package="rapidsplithalf")
Sercan Kahveci
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.